Mailing List
------------
The Falcon community maintains a mailing list that you can use to share
your ideas and ask questions about the framework. We use the appropriately
minimalistic `Librelist <http://librelist.com/>`_ to host the discussions.

To join the mailing list, simply send your first email to falcon@librelist.com!
This will automatically subscribe you to the mailing list *and* sends your email
along to the rest of the subscribers. For more information about managing your
subscription, check out the
`Librelist help page <http://librelist.com/help.html>`_.

All contributors and maintainers of this project are subject to our `Code
of Conduct <https://github.com/falconry/falcon/blob/master/CODEOFCONDUCT.md>`_.
We expect everyone who participates on the mailing list to act
professionally, and lead by example in encouraging constructive
discussions. Each individual in the community is responsible for creating
a positive, constructive, and productive culture.

`Discussions are archived <http://librelist.com/browser/falcon>`_
for posterity.

Submit Issues
-------------
If you have an idea for a feature, run into something that is harder to
use than it should be, or find a bug, please let the crew know
in **#falconframework** and/or by
`submitting an issue <https://github.com/racker/falcon/issues>`_. We
need your help to make Falcon awesome!

Pay it Forward
--------------
We'd like to invite you to help other community members with their
questions in IRC, and to peer-review
`pull requests <https://github.com/racker/falcon/pulls>`_. If you use the
Chrome browser, we recommend installing the
`NotHub extension <http://nothub.org/>`_ to stay up to date with PRs.

Code of Conduct
---------------
All contributors and maintainers of this project are subject to our `Code
of Conduct <https://github.com/falconry/falcon/blob/master/CODEOFCONDUCT.md>`_.
